@@ -14,6 +14,8 @@ struct login_settings {
 	const char *ssl_key_password;
 	const char *ssl_cipher_list;
 	const char *ssl_cert_username_field;
+	const char *ssl_client_cert;
+	const char *ssl_client_key;
 	bool ssl_verify_client_cert;
 	bool auth_ssl_require_client_cert;
 	bool auth_ssl_username_from_cert;
